Struct StringSignalBuilder
pub struct StringSignalBuilder {
measurement_name: Symbol,
buf: Box<[u8]>,
updated: BitVec,
has_changes: bool,
}Expand description
Helper for building a string signal from multiple character signals.
This type assumes that the individual character signals of a string signal are each sent exactly once before a character is updated again. A final string is only emitted once all characters have been updated and at this point the entire process repeats. If a character is updated again, we assume that we missed a character signal and reset the progress for the string, effectively discarding it. The order of characters is irrelevant.
To reduce the amount of string allocations, we only actually emit a new measurement if the string has changed compared to the last emitted string.
Fields
measurement_name: Symbolbuf: Box<[u8]>updated: BitVechas_changes: boolImplementations
impl StringSignalBuilder
impl StringSignalBuilder
pub fn new(measurement_name: Symbol, exact_len: usize) -> Self
fn reset_progress(&mut self)
fn update_buf(&mut self, idx: usize, byte: u8)
fn update_buf(&mut self, idx: usize, byte: u8)
Panics
Will panic if idx is out of range.
fn force_send(&self, meas_tx: &MeasurementTx, ts: DateTime<Utc>) -> bool
fn force_send(&self, meas_tx: &MeasurementTx, ts: DateTime<Utc>) -> bool
Forces the current buffer content to be sent as a measurement.
This function doesn’t check if the buffer is fully updated or if there are any changes. It does, however, refuse to send if the buffer content is not valid UTF-8.
Returns true if the measurement was sent and false otherwise.
fn dispatch(
&mut self,
meas_tx: &MeasurementTx,
ts: DateTime<Utc>,
idx: usize,
byte: u8,
) -> bool
fn dispatch( &mut self, meas_tx: &MeasurementTx, ts: DateTime<Utc>, idx: usize, byte: u8, ) -> bool
Dispatches a new byte for the character at the given index.
Returns true if a measurement was sent and false otherwise.
fn dispatch_physical(
&mut self,
meas_tx: &MeasurementTx,
ts: DateTime<Utc>,
idx: usize,
value: f64,
) -> bool
fn dispatch_physical( &mut self, meas_tx: &MeasurementTx, ts: DateTime<Utc>, idx: usize, value: f64, ) -> bool
Dispatches a new byte (as a physical value) for the character at the given index.
This function validates that the given “physical” value is a whole u8.
Any value that doesn’t correspond to a whole byte is rejected and won’t
be dispatched.
Returns true if a measurement was sent and false otherwise.